package sql;

import java.io.*;
import java.util.ArrayList;
import java.util.List;

/**
 * Created by gbrencic on 25.3.2016..
 */
public class CollectScriptsToOneFile {
    final int firstScript = 29;
    final int lastScript = 41;
    final File outputFile = new File("./commons-pos/resources/sql/ScriptsCollecton.sql");


    public CollectScriptsToOneFile() throws IOException {
        int current = firstScript;
        final File localDir = new File("./commons-pos/resources/sql/oracle");
        List<File> filesToWrite = new ArrayList<File>();

        for (File file : localDir.listFiles()) {
            try {
                if (isValidFile(file)) {
                    filesToWrite.add(file);
                }
            } catch (Exception e) {
                e.printStackTrace();
            }
        }

        collectAndWrite(outputFile, filesToWrite);
    }

    private void collectAndWrite(File outputFile, List<File> filesToWrite) throws IOException {
        if (null != outputFile && !outputFile.exists()) {
            outputFile.createNewFile();
        }

        FileWriter writer = new FileWriter(outputFile);
        BufferedWriter bufferedWriter = new BufferedWriter(writer);

        for (File file : filesToWrite) {

            bufferedWriter.write("-- Skripta: " + file.getName());
            bufferedWriter.newLine();
            bufferedWriter.write(getFileContent(file));
            bufferedWriter.newLine();
        }

        bufferedWriter.write(getDbVersionUpdateSql(lastScript));
        bufferedWriter.write("\n-- COMMIT \n COMMIT;");
        bufferedWriter.close();

    }

    private boolean isValidFile(File file) {
        if (null == file) return false;
        if (!file.getName().contains(".")) return false;

        final String fileNameNoExtension = file.getName().substring(0, file.getName().length() - 4);
        Integer fileNameInt = null;

        try {
            fileNameInt = Integer.valueOf(fileNameNoExtension);
        } catch (NumberFormatException e) {
            return false;
        }

        if (fileNameInt >= firstScript && fileNameInt <= lastScript) {
            System.out.println(fileNameInt);
            return true;
        }
        return false;
    }

    public String getFileContent(File aFile) {
        //...checks on aFile are elided
        StringBuilder contents = new StringBuilder();

        try {
            BufferedReader input = new BufferedReader(new FileReader(aFile));
            try {
                String line = null; //not declared within while loop
                while ((line = input.readLine()) != null) {
                    contents.append(line);
                    contents.append(System.getProperty("line.separator"));
                }
            } finally {
                input.close();
            }
        } catch (IOException ex) {
            ex.printStackTrace();
        }

        return contents.toString();
    }

    public static void main(String[] args) throws IOException {
        new CollectScriptsToOneFile();
    }


    private String getDbVersionUpdateSql(int lastScript) {
        return "-- UPDATE VERSION \n UPDATE M_POS_PARAMETAR SET value=" + lastScript + " WHERE key='version';";
    }
}
