CREATE TABLE M_POS_POREZNA_ISPORUKA
(
  ID                        NUMERIC                      NOT NULL,
  ID_KASE                   NUMERIC                      NOT NULL,
  SIFRA                     VARCHAR2(40)                 NOT NULL,
  NAZIV                     VARCHAR2(80)                 NOT NULL,
  STOPA                     NUMERIC(5,2)                         ,
  AKTIVNO                   VARCHAR2(1)   DEFAULT ('Y')  NOT NULL,
  GAS_ID                    NUMERIC                              ,
  VERZIJA                   NUMERIC                              ,
  UNOS_KORISNIK             VARCHAR2(60)                         ,
  UNOS_DATUM                DATE                                 ,
  IZMJENA_KORISNIK          VARCHAR2(60)                         ,
  IZMJENA_DATUM             DATE                                 ,
  CONSTRAINT M_POS_PI_1_CK CHECK ( AKTIVNO in ('Y','N') ),
  CONSTRAINT M_POS_PI_PK PRIMARY KEY (ID),
  CONSTRAINT M_POS_PI_UK UNIQUE (ID_KASE, SIFRA),
  CONSTRAINT M_POS_PI_1_FK FOREIGN KEY (ID_KASE) REFERENCES M_POS_KASE (ID)
);

CREATE TABLE M_POS_POREZNI_DOGADJAJ
(
  ID                        NUMERIC                      NOT NULL,
  ID_KASE                   NUMERIC                      NOT NULL,
  SIFRA                     VARCHAR2(40)                 NOT NULL,
  NAZIV                     VARCHAR2(80)                 NOT NULL,
  AKTIVNO                   VARCHAR2(1)   DEFAULT ('Y')  NOT NULL,
  GAS_ID                    NUMERIC                              ,
  VERZIJA                   NUMERIC                              ,
  UNOS_KORISNIK             VARCHAR2(60)                         ,
  UNOS_DATUM                DATE                                 ,
  IZMJENA_KORISNIK          VARCHAR2(60)                         ,
  IZMJENA_DATUM             DATE                                 ,
  CONSTRAINT M_POS_PD_1_CK CHECK ( AKTIVNO in ('Y','N') ),
  CONSTRAINT M_POS_PD_PK PRIMARY KEY (ID),
  CONSTRAINT M_POS_PD_UK UNIQUE (ID_KASE, SIFRA),
  CONSTRAINT M_POS_PD_1_FK FOREIGN KEY (ID_KASE) REFERENCES M_POS_KASE (ID)
);

CREATE TABLE M_POS_PID
(
  ID                        NUMERIC                      NOT NULL,
  POREZNI_DOGADJAJ_ID       NUMERIC                      NOT NULL,
  POCETNA_ISPORUKA_ID       NUMERIC                      NOT NULL,
  ZAVRSNA_ISPORUKA_ID       NUMERIC                      NOT NULL,
  AKTIVNO                   VARCHAR2(1)   DEFAULT ('Y')  NOT NULL,
  VERZIJA                   NUMERIC                              ,
  UNOS_KORISNIK             VARCHAR2(60)                         ,
  UNOS_DATUM                DATE                                 ,
  IZMJENA_KORISNIK          VARCHAR2(60)                         ,
  IZMJENA_DATUM             DATE                                 ,
  CONSTRAINT M_POS_PID_1_CK CHECK ( AKTIVNO in ('Y','N') ),
  CONSTRAINT M_POS_PID_PK PRIMARY KEY (ID),
  CONSTRAINT M_POS_PID_UK UNIQUE (POREZNI_DOGADJAJ_ID, POCETNA_ISPORUKA_ID),
  CONSTRAINT M_POS_PID_PD_FK FOREIGN KEY (POREZNI_DOGADJAJ_ID) REFERENCES M_POS_POREZNI_DOGADJAJ (ID),
  CONSTRAINT M_POS_PID_PI_FK FOREIGN KEY (ZAVRSNA_ISPORUKA_ID) REFERENCES M_POS_POREZNA_ISPORUKA (ID)
);

ALTER TABLE M_POS_POREZNE_GRUPE ADD POC_PI_ID NUMERIC;

ALTER TABLE M_POS_POREZNE_GRUPE ADD ZAV_PI_ID NUMERIC;

ALTER TABLE M_POS_POREZNE_GRUPE ADD (
  CONSTRAINT M_POS_PG_PI_FK FOREIGN KEY (ZAV_PI_ID) REFERENCES M_POS_POREZNA_ISPORUKA (ID));

CREATE INDEX M_POS_PG_PI_FK_I ON M_POS_POREZNE_GRUPE (ZAV_PI_ID);

ALTER TABLE M_POS_ARTIKLI DROP COLUMN DOZVOLJEN_POPUST;

ALTER TABLE M_POS_ARTIKLI_CJENIKA ADD MAKSIMALAN_POPUST NUMERIC(5,2) DEFAULT (0) NOT NULL;

ALTER TABLE M_POS_ARTIKLI_CJENIKA ADD OBAVEZAN_POPUST NUMERIC(5,2) DEFAULT (0) NOT NULL;

ALTER TABLE M_POS_KONOBARI ADD GAS_ID NUMERIC;

ALTER TABLE M_POS_CJENICI ADD GAS_ID NUMERIC;

ALTER TABLE M_POS_VRSTE_NAPLATE ADD GAS_ID NUMERIC;

ALTER TABLE M_POS_MJESTA_TROSKA ADD GAS_ID NUMERIC;

ALTER TABLE M_POS_POREZNE_GRUPE ADD GAS_ID NUMERIC;

ALTER TABLE M_POS_ARTIKLI ADD GAS_ID NUMERIC;

ALTER TABLE M_POS_KASE ADD GAS_ID NUMERIC;

UPDATE M_POS_KASE K SET GAS_ID = (SELECT ID_GASTRO_KASE FROM M_POS_GASTRO_PARAMETRI WHERE ID_KASE = K.ID);

DROP TABLE M_POS_GASTRO_PARAMETRI CASCADE CONSTRAINTS;

ALTER TABLE T_POS_RACUNI ADD POREZNI_DOGADJAJ_ID NUMERIC;

ALTER TABLE T_POS_RACUNI ADD (
  CONSTRAINT T_POS_RAC_PD_FK FOREIGN KEY (POREZNI_DOGADJAJ_ID) REFERENCES M_POS_POREZNI_DOGADJAJ (ID));

ALTER TABLE T_POS_STAVKE ADD POREZNA_ISPORUKA_ID NUMERIC;

ALTER TABLE T_POS_STAVKE ADD (
  CONSTRAINT T_POS_STAV_PI_FK FOREIGN KEY (POREZNA_ISPORUKA_ID) REFERENCES M_POS_POREZNA_ISPORUKA (ID));

ALTER TABLE T_POS_STAVKE ADD POPUST_POSTOTAK NUMERIC(5,4);

ALTER TABLE T_POS_STAVKE ADD POPUST NUMERIC(13,2);

DROP TABLE M_POS_ORDERMAN CASCADE CONSTRAINTS;
DROP TABLE M_POS_OMAN_SCANCODEAKCIJE CASCADE CONSTRAINTS;

CREATE TABLE M_POS_OMAN_SCANCODEAKCIJE
(
  ID                NUMERIC        NOT NULL,
  ID_KASE           NUMERIC        NOT NULL,
  SCANCODE          NUMERIC        NOT NULL,
  AKCIJA            VARCHAR2(100)   NOT NULL,
  VERZIJA           NUMERIC                ,
  UNOS_KORISNIK     VARCHAR2(60)           ,
  UNOS_DATUM        DATE                   ,
  IZMJENA_KORISNIK  VARCHAR2(60)           ,
  IZMJENA_DATUM     DATE                   ,
  CONSTRAINT M_POS_OMAN_PK PRIMARY KEY (ID),
  CONSTRAINT M_POS_OMAN_K_FK FOREIGN KEY (ID_KASE) REFERENCES M_POS_KASE (ID)
);
CREATE UNIQUE INDEX M_POS_OMAN_UK ON M_POS_OMAN_SCANCODEAKCIJE
(ID_KASE, SCANCODE);
CREATE INDEX M_POS_OMAN_K_FK_I ON M_POS_OMAN_SCANCODEAKCIJE
(ID_KASE);

ALTER TABLE T_POS_STAVKE ADD JEDINICNA_CIJENA_ORIGINAL NUMERIC(13,2) DEFAULT (0) NOT NULL;

UPDATE T_POS_STAVKE SET JEDINICNA_CIJENA_ORIGINAL = JEDINICNA_CIJENA;

ALTER TABLE T_POS_STAVKE MODIFY OSNOVICA_ZA_POREZ NUMERIC(21,10);

ALTER TABLE T_POS_STAVKE MODIFY PDV NUMERIC(21,10);

ALTER TABLE T_POS_STAVKE MODIFY PPOT NUMERIC(21,10);
